//line parser.y:2
package main

import __yyfmt__ "fmt"

//line parser.y:2
import (
	"bytes"
	"fmt"
	"io"
	"os"
)

type node struct {
	name       string
	children   []node
	attributes map[string]string
}

func (n node) String() string {
	buf := new(bytes.Buffer)
	n.print(buf, " ")
	return buf.String()
}

func (n node) print(out io.Writer, indent string) {
	if len(n.attributes) > 0 {
		fmt.Fprintf(out, "\n%v%v %s", indent, n.name, n.attributes)
	} else {
		fmt.Fprintf(out, "\n%v%v", indent, n.name)
	}
	for _, nn := range n.children {
		nn.print(out, indent+"  ")
	}
}

func Node(name string) node {
	return node{name: name, attributes: make(map[string]string)}
}

func (n node) append(nn ...node) node {
	n.children = append(n.children, nn...)
	return n
}

func (n node) attribute(key string, value string) node {
	n.attributes[key] = value
	return n
}

//line parser.y:50
type yySymType struct {
	yys   int
	node  node
	token string
	value string
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EVAL = 57348
const T_REQUIRE = 57349
const T_REQUIRE_ONCE = 57350
const T_LOGICAL_OR = 57351
const T_LOGICAL_XOR = 57352
const T_LOGICAL_AND = 57353
const T_PRINT = 57354
const T_YIELD = 57355
const T_DOUBLE_ARROW = 57356
const T_YIELD_FROM = 57357
const T_PLUS_EQUAL = 57358
const T_MINUS_EQUAL = 57359
const T_MUL_EQUAL = 57360
const T_DIV_EQUAL = 57361
const T_CONCAT_EQUAL = 57362
const T_MOD_EQUAL = 57363
const T_AND_EQUAL = 57364
const T_OR_EQUAL = 57365
const T_XOR_EQUAL = 57366
const T_SL_EQUAL = 57367
const T_SR_EQUAL = 57368
const T_POW_EQUAL = 57369
const T_COALESCE = 57370
const T_BOOLEAN_OR = 57371
const T_BOOLEAN_AND = 57372
const T_IS_EQUAL = 57373
const T_IS_NOT_EQUAL = 57374
const T_IS_IDENTICAL = 57375
const T_IS_NOT_IDENTICAL = 57376
const T_SPACESHIP = 57377
const T_IS_SMALLER_OR_EQUAL = 57378
const T_IS_GREATER_OR_EQUAL = 57379
const T_SL = 57380
const T_SR = 57381
const T_INSTANCEOF = 57382
const T_INC = 57383
const T_DEC = 57384
const T_INT_CAST = 57385
const T_DOUBLE_CAST = 57386
const T_STRING_CAST = 57387
const T_ARRAY_CAST = 57388
const T_OBJECT_CAST = 57389
const T_BOOL_CAST = 57390
const T_UNSET_CAST = 57391
const T_POW = 57392
const T_NEW = 57393
const T_CLONE = 57394
const T_NOELSE = 57395
const T_ELSEIF = 57396
const T_ELSE = 57397
const T_ENDIF = 57398
const T_STATIC = 57399
const T_ABSTRACT = 57400
const T_FINAL = 57401
const T_PRIVATE = 57402
const T_PROTECTED = 57403
const T_PUBLIC = 57404
const T_EXIT = 57405
const T_IF = 57406
const T_LNUMBER = 57407
const T_DNUMBER = 57408
const T_STRING = 57409
const T_STRING_VARNAME = 57410
const T_VARIABLE = 57411
const T_NUM_STRING = 57412
const T_INLINE_HTML = 57413
const T_CHARACTER = 57414
const T_BAD_CHARACTER = 57415
const T_ENCAPSED_AND_WHITESPACE = 57416
const T_CONSTANT_ENCAPSED_STRING = 57417
const T_ECHO = 57418
const T_DO = 57419
const T_WHILE = 57420
const T_ENDWHILE = 57421
const T_FOR = 57422
const T_ENDFOR = 57423
const T_FOREACH = 57424
const T_ENDFOREACH = 57425
const T_DECLARE = 57426
const T_ENDDECLARE = 57427
const T_AS = 57428
const T_SWITCH = 57429
const T_ENDSWITCH = 57430
const T_CASE = 57431
const T_DEFAULT = 57432
const T_BREAK = 57433
const T_CONTINUE = 57434
const T_GOTO = 57435
const T_FUNCTION = 57436
const T_CONST = 57437
const T_RETURN = 57438
const T_TRY = 57439
const T_CATCH = 57440
const T_FINALLY = 57441
const T_THROW = 57442
const T_USE = 57443
const T_INSTEADOF = 57444
const T_GLOBAL = 57445
const T_VAR = 57446
const T_UNSET = 57447
const T_ISSET = 57448
const T_EMPTY = 57449
const T_HALT_COMPILER = 57450
const T_CLASS = 57451
const T_TRAIT = 57452
const T_INTERFACE = 57453
const T_EXTENDS = 57454
const T_IMPLEMENTS = 57455
const T_OBJECT_OPERATOR = 57456
const T_LIST = 57457
const T_ARRAY = 57458
const T_CALLABLE = 57459
const T_CLASS_C = 57460
const T_TRAIT_C = 57461
const T_METHOD_C = 57462
const T_FUNC_C = 57463
const T_LINE = 57464
const T_FILE = 57465
const T_COMMENT = 57466
const T_DOC_COMMENT = 57467
const T_OPEN_TAG = 57468
const T_OPEN_TAG_WITH_ECHO = 57469
const T_CLOSE_TAG = 57470
const T_WHITESPACE = 57471
const T_START_HEREDOC = 57472
const T_END_HEREDOC = 57473
const T_DOLLAR_OPEN_CURLY_BRACES = 57474
const T_CURLY_OPEN = 57475
const T_PAAMAYIM_NEKUDOTAYIM = 57476
const T_NAMESPACE = 57477
const T_NS_C = 57478
const T_DIR = 57479
const T_NS_SEPARATOR = 57480
const T_ELLIPSIS = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"','",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_PRINT",
	"T_YIELD",
	"T_DOUBLE_ARROW",
	"T_YIELD_FROM",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"'?'",
	"':'",
	"T_COALESCE",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"'&'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_SPACESHIP",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'+'",
	"'-'",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"'!'",
	"T_INSTANCEOF",
	"'~'",
	"T_INC",
	"T_DEC",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"'@'",
	"T_POW",
	"'['",
	"T_NEW",
	"T_CLONE",
	"T_NOELSE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"'('",
	"')'",
	"';'",
	"'{'",
	"'}'",
	"']'",
	"'\"'",
	"'$'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line parser.y:1061
const src = `<?php
use A, B as C;
use \D\{function E, F};
`

func main() {
	yyDebug = 0
	yyErrorVerbose = true
	l := newLexer(bytes.NewBufferString(src), os.Stdout, "file.name")
	yyParse(l)
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 38,
	133, 393,
	153, 393,
	-2, 399,
	-1, 76,
	133, 395,
	153, 395,
	-2, 370,
	-1, 92,
	153, 391,
	-2, 387,
	-1, 196,
	133, 393,
	153, 393,
	-2, 299,
	-1, 202,
	133, 393,
	153, 393,
	-2, 301,
	-1, 302,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 323,
	-1, 303,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 324,
	-1, 304,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 325,
	-1, 305,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 326,
	-1, 306,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 327,
	-1, 307,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 328,
	-1, 308,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 329,
	-1, 309,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 330,
	-1, 310,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 331,
	-1, 316,
	133, 393,
	153, 393,
	-2, 208,
	-1, 354,
	133, 394,
	153, 394,
	-2, 332,
	-1, 454,
	133, 393,
	153, 393,
	-2, 191,
	-1, 488,
	160, 263,
	-2, 268,
	-1, 539,
	133, 393,
	153, 393,
	-2, 179,
	-1, 565,
	88, 242,
	-2, 248,
	-1, 583,
	133, 393,
	153, 393,
	-2, 190,
	-1, 603,
	133, 393,
	153, 393,
	-2, 180,
	-1, 650,
	133, 397,
	153, 397,
	-2, 182,
	-1, 713,
	105, 76,
	-2, 78,
	-1, 730,
	160, 263,
	-2, 268,
}

const yyPrivate = 57344

const yyLast = 6366

var yyAct = [...]int{

	24, 112, 664, 654, 567, 362, 549, 621, 705, 663,
	680, 645, 617, 553, 481, 168, 551, 538, 119, 119,
	119, 522, 554, 131, 266, 271, 239, 4, 521, 586,
	92, 165, 596, 315, 76, 319, 490, 267, 268, 114,
	5, 6, 130, 127, 124, 650, 195, 241, 90, 203,
	204, 205, 206, 207, 110, 209, 210, 111, 212, 213,
	214, 215, 216, 217, 218, 219, 220, 221, 2, 222,
	223, 224, 75, 667, 74, 580, 38, 201, 201, 451,
	714, 200, 200, 760, 761, 73, 571, 572, 573, 570,
	569, 568, 676, 673, 671, 243, 633, 90, 348, 509,
	90, 230, 510, 752, 534, 693, 125, 640, 641, 640,
	641, 246, 681, 653, 269, 250, 251, 273, 274, 198,
	198, 197, 197, 196, 202, 456, 91, 102, 456, 456,
	564, 489, 456, 566, 285, 286, 287, 288, 289, 290,
	291, 292, 293, 294, 295, 296, 297, 298, 299, 300,
	301, 302, 303, 304, 305, 306, 307, 308, 309, 310,
	311, 313, 683, 317, 639, 263, 321, 231, 326, 164,
	252, 236, 442, 615, 349, 91, 755, 237, 91, 332,
	334, 335, 336, 337, 338, 339, 340, 341, 342, 343,
	344, 345, 201, 508, 346, 740, 200, 96, 99, 328,
	353, 588, 102, 101, 525, 519, 100, 106, 467, 355,
	699, 660, 356, 571, 572, 573, 570, 569, 568, 734,
	733, 720, 689, 684, 677, 668, 669, 637, 358, 436,
	232, 233, 626, 445, 198, 533, 197, 449, 316, 243,
	99, 600, 682, 599, 448, 259, 284, 281, 279, 259,
	597, 557, 558, 595, 472, 485, 460, 564, 602, 457,
	566, 330, 323, 277, 201, 450, 276, 275, 200, 94,
	115, 253, 753, 97, 741, 201, 120, 4, 688, 200,
	350, 687, 678, 477, 672, 131, 102, 610, 90, 585,
	5, 6, 536, 512, 95, 247, 248, 249, 730, 652,
	560, 604, 256, 584, 488, 262, 198, 471, 197, 455,
	447, 359, 437, 480, 464, 263, 329, 198, 327, 197,
	458, 454, 238, 211, 475, 476, 208, 478, 491, 439,
	492, 441, 193, 493, 494, 93, 441, 439, 163, 555,
	102, 162, 161, 117, 116, 113, 98, 135, 137, 136,
	496, 658, 261, 246, 115, 261, 737, 97, 500, 199,
	352, 351, 698, 659, 226, 125, 91, 159, 102, 160,
	133, 134, 138, 140, 139, 152, 153, 150, 151, 154,
	155, 156, 157, 158, 148, 149, 142, 143, 141, 144,
	146, 147, 135, 137, 136, 102, 261, 461, 283, 280,
	278, 258, 225, 601, 246, 145, 484, 520, 115, 261,
	261, 97, 159, 102, 160, 133, 134, 138, 140, 139,
	152, 153, 150, 151, 154, 155, 156, 157, 158, 148,
	149, 142, 143, 141, 144, 146, 147, 359, 437, 465,
	108, 109, 231, 443, 557, 558, 194, 442, 469, 735,
	145, 102, 736, 243, 514, 463, 243, 466, 608, 609,
	105, 462, 260, 115, 102, 231, 97, 270, 581, 231,
	227, 231, 529, 273, 531, 231, 235, 620, 619, 229,
	535, 618, 517, 4, 107, 695, 128, 547, 724, 71,
	72, 108, 109, 102, 320, 527, 5, 6, 530, 506,
	513, 628, 468, 456, 440, 232, 233, 444, 325, 544,
	582, 324, 172, 201, 201, 166, 537, 200, 200, 556,
	577, 546, 257, 263, 145, 523, 559, 228, 232, 233,
	593, 438, 232, 233, 232, 233, 589, 169, 232, 233,
	170, 723, 613, 243, 40, 579, 201, 606, 173, 174,
	200, 685, 640, 641, 592, 198, 198, 197, 197, 316,
	539, 643, 640, 641, 504, 255, 655, 598, 234, 605,
	623, 201, 175, 177, 176, 200, 625, 587, 614, 171,
	627, 331, 591, 523, 167, 243, 556, 727, 198, 700,
	197, 661, 583, 486, 282, 622, 273, 667, 631, 624,
	502, 630, 505, 503, 524, 243, 590, 635, 144, 146,
	147, 629, 634, 198, 104, 197, 611, 603, 632, 118,
	648, 638, 482, 473, 145, 452, 646, 670, 656, 1,
	642, 649, 644, 201, 103, 254, 665, 200, 121, 122,
	347, 679, 556, 43, 44, 89, 587, 675, 523, 686,
	501, 67, 759, 708, 709, 692, 571, 572, 573, 570,
	569, 568, 697, 466, 707, 466, 706, 704, 701, 694,
	666, 563, 711, 696, 662, 198, 616, 197, 565, 539,
	562, 561, 719, 691, 607, 690, 556, 548, 543, 674,
	718, 318, 242, 240, 314, 726, 129, 126, 702, 722,
	710, 729, 123, 716, 532, 715, 272, 711, 526, 728,
	12, 37, 646, 732, 11, 36, 42, 466, 39, 738,
	739, 550, 466, 466, 552, 34, 264, 3, 744, 361,
	657, 612, 0, 0, 0, 710, 0, 745, 0, 0,
	750, 749, 748, 746, 148, 149, 142, 143, 141, 144,
	146, 147, 754, 0, 756, 742, 0, 757, 0, 0,
	0, 556, 0, 762, 0, 145, 622, 369, 370, 371,
	372, 373, 136, 374, 375, 376, 412, 413, 0, 0,
	0, 0, 0, 0, 0, 0, 466, 0, 466, 0,
	159, 0, 160, 133, 134, 138, 140, 139, 152, 153,
	150, 151, 154, 155, 156, 157, 158, 148, 149, 142,
	143, 141, 144, 146, 147, 0, 0, 0, 0, 377,
	0, 0, 0, 0, 0, 0, 0, 0, 145, 466,
	0, 0, 0, 378, 379, 0, 382, 383, 384, 363,
	364, 365, 366, 367, 368, 380, 381, 0, 0, 360,
	0, 90, 0, 0, 0, 0, 0, 0, 385, 386,
	387, 388, 389, 390, 391, 392, 393, 394, 395, 415,
	416, 417, 418, 419, 407, 408, 409, 410, 411, 396,
	397, 398, 399, 400, 401, 402, 403, 404, 405, 406,
	0, 427, 425, 426, 422, 423, 0, 414, 420, 421,
	428, 429, 431, 430, 432, 433, 369, 370, 371, 372,
	373, 0, 374, 375, 376, 412, 413, 424, 435, 434,
	0, 0, 0, 0, 0, 0, 0, 0, 159, 91,
	160, 133, 134, 138, 140, 139, 152, 153, 150, 151,
	154, 155, 156, 157, 158, 148, 149, 142, 143, 141,
	144, 146, 147, 0, 0, 0, 0, 0, 377, 0,
	0, 0, 0, 0, 0, 0, 145, 0, 0, 0,
	0, 0, 378, 379, 0, 382, 383, 384, 363, 364,
	365, 366, 367, 368, 380, 381, 0, 0, 713, 0,
	0, 0, 0, 0, 0, 0, 0, 385, 386, 387,
	388, 389, 390, 391, 392, 393, 394, 395, 415, 416,
	417, 418, 419, 407, 408, 409, 410, 411, 396, 397,
	398, 399, 400, 401, 402, 403, 404, 405, 406, 0,
	427, 425, 426, 422, 423, 0, 414, 420, 421, 428,
	429, 431, 430, 432, 433, 369, 370, 371, 372, 373,
	0, 374, 375, 376, 412, 413, 712, 435, 434, 97,
	0, 0, 0, 0, 0, 731, 160, 133, 134, 138,
	140, 139, 152, 153, 150, 151, 154, 155, 156, 157,
	158, 148, 149, 142, 143, 141, 144, 146, 147, 142,
	143, 141, 144, 146, 147, 0, 0, 377, 0, 0,
	0, 0, 145, 0, 0, 0, 0, 0, 145, 0,
	0, 378, 379, 0, 382, 383, 384, 363, 364, 365,
	366, 367, 368, 380, 381, 0, 0, 713, 0, 0,
	0, 0, 0, 0, 0, 0, 385, 386, 387, 388,
	389, 390, 391, 392, 393, 394, 395, 415, 416, 417,
	418, 419, 407, 408, 409, 410, 411, 396, 397, 398,
	399, 400, 401, 402, 403, 404, 405, 406, 0, 427,
	425, 426, 422, 423, 0, 414, 420, 421, 428, 429,
	431, 430, 432, 433, 0, 0, 0, 0, 0, 0,
	54, 55, 56, 57, 58, 712, 435, 434, 97, 68,
	69, 0, 70, 0, 703, 134, 138, 140, 139, 152,
	153, 150, 151, 154, 155, 156, 157, 158, 148, 149,
	142, 143, 141, 144, 146, 147, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 48, 49, 0, 0, 145,
	0, 50, 0, 51, 46, 47, 59, 60, 61, 62,
	63, 64, 65, 66, 0, 94, 0, 45, 0, 0,
	0, 0, 21, 71, 72, 0, 0, 0, 0, 41,
	77, 78, 32, 0, 90, 0, 23, 0, 0, 0,
	95, 22, 14, 13, 0, 15, 0, 26, 0, 27,
	0, 0, 16, 0, 0, 0, 17, 18, 31, 33,
	0, 19, 29, 0, 0, 30, 9, 0, 20, 0,
	25, 0, 53, 7, 35, 0, 0, 0, 0, 0,
	0, 93, 0, 86, 82, 83, 84, 79, 80, 0,
	0, 0, 0, 0, 0, 87, 0, 0, 0, 0,
	8, 85, 81, 97, 0, 52, 0, 28, 10, 518,
	0, 88, 91, 54, 55, 56, 57, 58, 0, 0,
	0, 0, 68, 69, 0, 70, 0, 138, 140, 139,
	152, 153, 150, 151, 154, 155, 156, 157, 158, 148,
	149, 142, 143, 141, 144, 146, 147, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 48, 49,
	145, 0, 0, 0, 50, 0, 51, 46, 47, 59,
	60, 61, 62, 63, 64, 65, 66, 0, 94, 0,
	45, 0, 0, 0, 0, 21, 71, 72, 0, 0,
	0, 0, 41, 77, 78, 32, 0, 90, 0, 23,
	0, 0, 0, 95, 22, 14, 13, 0, 15, 0,
	26, 0, 27, 0, 0, 16, 0, 0, 0, 17,
	18, 31, 33, 0, 19, 29, 0, 0, 30, 9,
	0, 20, 0, 25, 0, 53, 7, 35, 0, 0,
	0, 0, 0, 0, 93, 0, 86, 82, 83, 84,
	79, 80, 0, 0, 0, 0, 0, 0, 87, 0,
	0, 0, 0, 8, 85, 81, 97, 0, 52, 0,
	28, 10, 459, 0, 88, 91, 54, 55, 56, 57,
	58, 0, 0, 0, 0, 68, 69, 0, 70, 0,
	0, 140, 139, 152, 153, 150, 151, 154, 155, 156,
	157, 158, 148, 149, 142, 143, 141, 144, 146, 147,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 48, 49, 145, 0, 0, 0, 50, 0, 51,
	46, 47, 59, 60, 61, 62, 63, 64, 65, 66,
	0, 94, 0, 45, 0, 0, 0, 0, 21, 71,
	72, 0, 0, 0, 0, 41, 77, 78, 32, 0,
	90, 0, 23, 0, 0, 0, 95, 22, 14, 13,
	0, 15, 0, 26, 0, 27, 0, 0, 16, 0,
	0, 0, 17, 18, 31, 33, 0, 19, 29, 0,
	0, 30, 9, 0, 20, 0, 25, 0, 53, 7,
	35, 0, 0, 0, 0, 0, 0, 93, 0, 86,
	82, 83, 84, 79, 80, 0, 0, 0, 0, 0,
	0, 87, 0, 0, 0, 0, 8, 85, 81, 97,
	0, 52, 0, 28, 10, 357, 0, 88, 91, 54,
	55, 56, 57, 58, 0, 0, 0, 0, 68, 69,
	159, 70, 160, 133, 134, 138, 140, 139, 152, 153,
	150, 151, 154, 155, 156, 157, 158, 148, 149, 142,
	143, 141, 144, 146, 147, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 48, 49, 0, 0, 145, 0,
	50, 0, 51, 46, 47, 59, 60, 61, 62, 63,
	64, 65, 66, 0, 94, 0, 45, 0, 0, 0,
	0, 21, 71, 72, 0, 0, 0, 0, 41, 77,
	78, 32, 0, 90, 0, 23, 0, 0, 0, 95,
	22, 14, 13, 0, 15, 0, 26, 0, 27, 0,
	0, 16, 0, 0, 0, 17, 18, 31, 33, 0,
	19, 29, 0, 0, 30, 0, 0, 20, 0, 25,
	0, 53, 0, 35, 0, 0, 0, 0, 0, 0,
	93, 0, 86, 82, 83, 84, 79, 80, 0, 0,
	0, 0, 0, 0, 87, 0, 0, 0, 0, 115,
	85, 81, 97, 0, 52, 0, 28, 10, 763, 0,
	88, 91, 54, 55, 56, 57, 58, 0, 0, 0,
	0, 68, 69, 0, 70, 139, 152, 153, 150, 151,
	154, 155, 156, 157, 158, 148, 149, 142, 143, 141,
	144, 146, 147, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 145, 48, 49, 0,
	0, 0, 0, 50, 0, 51, 46, 47, 59, 60,
	61, 62, 63, 64, 65, 66, 0, 94, 0, 45,
	0, 0, 0, 0, 21, 71, 72, 0, 0, 0,
	0, 41, 77, 78, 32, 0, 90, 0, 23, 0,
	0, 0, 95, 22, 14, 13, 0, 15, 0, 26,
	0, 27, 0, 0, 16, 0, 0, 0, 17, 18,
	31, 33, 0, 19, 29, 0, 0, 30, 0, 0,
	20, 0, 25, 0, 53, 0, 35, 0, 0, 0,
	0, 0, 0, 93, 0, 86, 82, 83, 84, 79,
	80, 0, 0, 0, 0, 0, 0, 87, 0, 0,
	0, 0, 115, 85, 81, 97, 0, 52, 0, 28,
	10, 758, 0, 88, 91, 54, 55, 56, 57, 58,
	0, 0, 0, 0, 68, 69, 0, 70, 152, 153,
	150, 151, 154, 155, 156, 157, 158, 148, 149, 142,
	143, 141, 144, 146, 147, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 145, 0,
	48, 49, 0, 0, 0, 0, 50, 0, 51, 46,
	47, 59, 60, 61, 62, 63, 64, 65, 66, 0,
	94, 0, 45, 0, 0, 0, 0, 21, 71, 72,
	0, 0, 0, 0, 41, 77, 78, 32, 0, 90,
	0, 23, 0, 0, 0, 95, 22, 14, 13, 0,
	15, 751, 26, 0, 27, 0, 0, 16, 0, 0,
	0, 17, 18, 31, 33, 0, 19, 29, 0, 0,
	30, 0, 0, 20, 0, 25, 0, 53, 0, 35,
	0, 0, 0, 0, 0, 0, 93, 0, 86, 82,
	83, 84, 79, 80, 0, 0, 0, 0, 0, 0,
	87, 0, 0, 0, 0, 115, 85, 81, 97, 0,
	52, 0, 28, 10, 0, 0, 88, 91, 54, 55,
	56, 57, 58, 0, 0, 0, 0, 68, 69, 0,
	70, 155, 156, 157, 158, 148, 149, 142, 143, 141,
	144, 146, 147, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 145, 0, 0, 0,
	0, 0, 0, 48, 49, 0, 0, 0, 0, 50,
	0, 51, 46, 47, 59, 60, 61, 62, 63, 64,
	65, 66, 0, 94, 0, 45, 0, 0, 0, 0,
	21, 71, 72, 0, 0, 0, 0, 41, 77, 78,
	32, 0, 90, 0, 23, 0, 0, 0, 95, 22,
	14, 13, 0, 15, 0, 26, 0, 27, 0, 0,
	16, 0, 0, 0, 17, 18, 31, 33, 0, 19,
	29, 0, 0, 30, 0, 0, 20, 0, 25, 0,
	53, 0, 35, 0, 0, 0, 0, 0, 0, 93,
	0, 86, 82, 83, 84, 79, 80, 0, 0, 0,
	0, 0, 0, 87, 0, 0, 0, 0, 115, 85,
	81, 97, 0, 52, 0, 28, 10, 743, 0, 88,
	91, 54, 55, 56, 57, 58, 0, 0, 0, 0,
	68, 69, 0, 70, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 178, 179,
	180, 181, 183, 184, 185, 186, 187, 188, 189, 190,
	182, 0, 0, 0, 0, 0, 48, 49, 0, 0,
	0, 0, 50, 0, 51, 46, 47, 59, 60, 61,
	62, 63, 64, 65, 66, 0, 94, 0, 45, 191,
	192, 0, 0, 21, 71, 72, 0, 0, 0, 0,
	41, 77, 78, 32, 0, 90, 0, 23, 0, 0,
	0, 95, 22, 14, 13, 0, 15, 0, 26, 0,
	27, 0, 0, 16, 0, 0, 0, 17, 18, 31,
	33, 0, 19, 29, 0, 0, 30, 0, 0, 20,
	0, 25, 0, 53, 0, 35, 0, 0, 0, 0,
	0, 0, 93, 0, 86, 82, 83, 84, 79, 80,
	0, 0, 0, 0, 0, 0, 87, 0, 0, 0,
	0, 115, 85, 81, 97, 0, 52, 0, 28, 10,
	725, 0, 88, 91, 54, 55, 56, 57, 58, 0,
	0, 0, 0, 68, 69, 0, 70, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 48,
	49, 0, 0, 0, 0, 50, 0, 51, 46, 47,
	59, 60, 61, 62, 63, 64, 65, 66, 0, 94,
	0, 45, 0, 0, 0, 0, 21, 71, 72, 0,
	0, 0, 0, 41, 77, 78, 32, 0, 90, 0,
	23, 0, 0, 0, 95, 22, 14, 13, 0, 15,
	0, 26, 721, 27, 0, 0, 16, 0, 0, 0,
	17, 18, 31, 33, 0, 19, 29, 0, 0, 30,
	0, 0, 20, 0, 25, 0, 53, 0, 35, 0,
	0, 0, 0, 0, 0, 93, 0, 86, 82, 83,
	84, 79, 80, 0, 0, 0, 0, 0, 0, 87,
	0, 0, 0, 0, 115, 85, 81, 97, 0, 52,
	0, 28, 10, 0, 0, 88, 91, 54, 55, 56,
	57, 58, 0, 0, 0, 0, 68, 69, 0, 70,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 48, 49, 0, 0, 0, 0, 50, 0,
	51, 46, 47, 59, 60, 61, 62, 63, 64, 65,
	66, 0, 94, 0, 45, 0, 0, 0, 0, 21,
	71, 72, 0, 0, 0, 0, 41, 77, 78, 32,
	0, 90, 0, 23, 0, 0, 0, 95, 22, 14,
	13, 0, 15, 0, 26, 0, 27, 651, 0, 16,
	0, 0, 0, 17, 18, 31, 33, 0, 19, 29,
	0, 0, 30, 0, 0, 20, 0, 25, 0, 53,
	0, 35, 0, 0, 0, 0, 0, 0, 93, 0,
	86, 82, 83, 84, 79, 80, 0, 0, 0, 0,
	0, 0, 87, 0, 0, 0, 0, 115, 85, 81,
	97, 0, 52, 0, 28, 10, 0, 0, 88, 91,
	54, 55, 56, 57, 58, 0, 0, 0, 0, 68,
	69, 0, 70, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 48, 49, 0, 0, 0,
	0, 50, 0, 51, 46, 47, 59, 60, 61, 62,
	63, 64, 65, 66, 0, 94, 0, 45, 0, 0,
	0, 0, 21, 71, 72, 0, 0, 0, 0, 41,
	77, 78, 32, 0, 90, 0, 23, 0, 0, 0,
	95, 22, 14, 13, 636, 15, 0, 26, 0, 27,
	0, 0, 16, 0, 0, 0, 17, 18, 31, 33,
	0, 19, 29, 0, 0, 30, 0, 0, 20, 0,
	25, 0, 53, 0, 35, 0, 0, 0, 0, 0,
	0, 93, 0, 86, 82, 83, 84, 79, 80, 0,
	0, 0, 0, 0, 0, 87, 0, 0, 0, 0,
	115, 85, 81, 97, 0, 52, 0, 28, 10, 0,
	0, 88, 91, 54, 55, 56, 57, 58, 0, 0,
	0, 0, 68, 69, 0, 70, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 48, 49,
	0, 0, 0, 0, 50, 0, 51, 46, 47, 59,
	60, 61, 62, 63, 64, 65, 66, 0, 94, 0,
	45, 0, 0, 0, 576, 21, 71, 72, 0, 0,
	0, 0, 41, 77, 78, 32, 0, 90, 0, 23,
	0, 0, 0, 95, 22, 14, 13, 0, 15, 0,
	26, 0, 27, 0, 0, 16, 0, 0, 0, 17,
	18, 31, 33, 0, 19, 29, 0, 0, 30, 0,
	0, 20, 0, 25, 0, 53, 0, 35, 0, 0,
	0, 0, 0, 0, 93, 0, 86, 82, 83, 84,
	79, 80, 0, 0, 0, 0, 0, 0, 87, 0,
	0, 0, 0, 115, 85, 81, 97, 0, 52, 0,
	28, 10, 0, 0, 88, 91, 54, 55, 56, 57,
	58, 0, 0, 0, 0, 68, 69, 0, 70, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 48, 49, 0, 0, 0, 0, 50, 0, 51,
	46, 47, 59, 60, 61, 62, 63, 64, 65, 66,
	0, 94, 0, 45, 0, 0, 0, 0, 21, 71,
	72, 0, 0, 0, 0, 41, 77, 78, 32, 0,
	90, 0, 23, 0, 0, 0, 95, 22, 14, 13,
	0, 15, 0, 26, 0, 27, 0, 0, 16, 0,
	0, 0, 17, 18, 31, 33, 0, 19, 29, 0,
	0, 30, 0, 0, 20, 0, 25, 0, 53, 0,
	35, 0, 0, 0, 0, 0, 0, 93, 0, 86,
	82, 83, 84, 79, 80, 0, 0, 0, 0, 0,
	0, 87, 0, 0, 0, 0, 115, 85, 81, 97,
	0, 52, 0, 28, 10, 487, 0, 88, 91, 54,
	55, 56, 57, 58, 0, 0, 0, 0, 68, 69,
	0, 70, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 48, 49, 0, 0, 0, 0,
	50, 0, 51, 46, 47, 59, 60, 61, 62, 63,
	64, 65, 66, 0, 94, 0, 45, 0, 0, 0,
	0, 21, 71, 72, 0, 0, 0, 0, 41, 77,
	78, 32, 0, 90, 0, 23, 0, 0, 0, 95,
	22, 14, 13, 0, 15, 0, 26, 0, 27, 0,
	0, 16, 0, 0, 0, 17, 18, 31, 33, 0,
	19, 29, 0, 0, 30, 0, 0, 20, 0, 25,
	0, 53, 0, 35, 0, 0, 0, 0, 0, 0,
	93, 0, 86, 82, 83, 84, 79, 80, 0, 0,
	0, 0, 0, 0, 87, 0, 0, 0, 0, 115,
	85, 81, 97, 0, 52, 0, 28, 10, 265, 0,
	88, 91, 54, 55, 56, 57, 58, 0, 0, 0,
	0, 68, 69, 0, 70, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 48, 49, 0,
	0, 0, 0, 50, 0, 51, 46, 47, 59, 60,
	61, 62, 63, 64, 65, 66, 0, 94, 0, 45,
	0, 0, 0, 0, 21, 71, 72, 0, 0, 0,
	0, 41, 77, 78, 32, 0, 90, 0, 23, 0,
	0, 0, 95, 22, 14, 13, 0, 15, 0, 26,
	0, 27, 0, 0, 16, 0, 0, 0, 17, 18,
	31, 33, 0, 19, 29, 0, 0, 30, 0, 0,
	20, 0, 25, 0, 53, 0, 35, 0, 0, 0,
	0, 0, 0, 93, 0, 86, 82, 83, 84, 79,
	80, 0, 0, 0, 0, 0, 0, 87, 0, 0,
	0, 0, 115, 85, 81, 97, 0, 52, 0, 28,
	10, 0, 0, 88, 91, 54, 55, 56, 57, 58,
	0, 0, 0, 0, 68, 69, 0, 70, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 647, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	48, 49, 0, 0, 0, 0, 50, 0, 51, 46,
	47, 59, 60, 61, 62, 63, 64, 65, 66, 0,
	94, 0, 45, 0, 0, 0, 0, 21, 0, 0,
	0, 0, 0, 0, 41, 77, 78, 32, 0, 90,
	0, 23, 0, 0, 0, 95, 22, 14, 13, 0,
	15, 0, 26, 0, 27, 0, 0, 16, 0, 0,
	0, 17, 18, 31, 0, 0, 19, 29, 0, 0,
	30, 0, 0, 20, 0, 25, 0, 53, 0, 0,
	0, 0, 0, 0, 0, 0, 93, 0, 86, 82,
	83, 84, 79, 80, 0, 0, 0, 0, 0, 0,
	87, 0, 0, 0, 0, 115, 85, 81, 97, 0,
	52, 0, 28, 10, 0, 0, 88, 91, 54, 55,
	56, 57, 58, 0, 0, 0, 0, 68, 69, 0,
	70, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 717, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 48, 49, 0, 0, 0, 0, 50,
	0, 51, 46, 47, 59, 60, 61, 62, 63, 64,
	65, 66, 0, 94, 0, 45, 0, 0, 0, 0,
	21, 0, 0, 0, 0, 0, 0, 41, 77, 78,
	32, 0, 90, 0, 23, 0, 0, 0, 95, 22,
	14, 13, 0, 15, 0, 26, 0, 27, 0, 0,
	16, 0, 0, 0, 17, 18, 31, 0, 0, 19,
	29, 0, 0, 30, 0, 0, 20, 0, 25, 0,
	53, 0, 0, 0, 0, 0, 0, 0, 0, 93,
	0, 86, 82, 83, 84, 79, 80, 0, 0, 0,
	0, 0, 0, 87, 0, 0, 0, 0, 115, 85,
	81, 97, 0, 52, 0, 28, 10, 0, 0, 88,
	91, 54, 55, 56, 57, 58, 0, 0, 0, 0,
	68, 69, 0, 70, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 578, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 48, 49, 0, 0,
	0, 0, 50, 0, 51, 46, 47, 59, 60, 61,
	62, 63, 64, 65, 66, 0, 94, 0, 45, 0,
	0, 0, 0, 21, 0, 0, 0, 0, 0, 0,
	41, 77, 78, 32, 0, 90, 0, 23, 0, 0,
	0, 95, 22, 14, 13, 0, 15, 0, 26, 0,
	27, 0, 0, 16, 0, 0, 0, 17, 18, 31,
	0, 0, 19, 29, 0, 0, 30, 0, 0, 20,
	0, 25, 0, 53, 0, 0, 0, 0, 0, 0,
	0, 0, 93, 0, 86, 82, 83, 84, 79, 80,
	0, 0, 0, 0, 0, 0, 87, 0, 0, 0,
	0, 115, 85, 81, 97, 0, 52, 0, 28, 10,
	0, 0, 88, 91, 54, 55, 56, 57, 58, 0,
	0, 0, 0, 68, 69, 0, 70, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 545, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 48,
	49, 0, 0, 0, 0, 50, 0, 51, 46, 47,
	59, 60, 61, 62, 63, 64, 65, 66, 0, 94,
	0, 45, 0, 0, 0, 0, 21, 0, 0, 0,
	0, 0, 0, 41, 77, 78, 32, 0, 90, 0,
	23, 0, 0, 0, 95, 22, 14, 13, 0, 15,
	0, 26, 0, 27, 0, 0, 16, 0, 0, 0,
	17, 18, 31, 0, 0, 19, 29, 0, 0, 30,
	0, 0, 20, 0, 25, 0, 53, 0, 0, 0,
	0, 0, 0, 0, 0, 93, 0, 86, 82, 83,
	84, 79, 80, 0, 0, 0, 0, 0, 0, 87,
	0, 0, 0, 0, 115, 85, 81, 97, 0, 52,
	0, 28, 10, 0, 0, 88, 91, 54, 55, 56,
	57, 58, 0, 0, 0, 0, 68, 69, 0, 70,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 528, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 48, 49, 0, 0, 0, 0, 50, 0,
	51, 46, 47, 59, 60, 61, 62, 63, 64, 65,
	66, 0, 94, 0, 45, 0, 0, 0, 0, 21,
	0, 0, 0, 0, 0, 0, 41, 77, 78, 32,
	0, 90, 0, 23, 0, 0, 0, 95, 22, 14,
	13, 0, 15, 0, 26, 0, 27, 0, 0, 16,
	0, 0, 0, 17, 18, 31, 0, 0, 19, 29,
	0, 0, 30, 0, 0, 20, 0, 25, 0, 53,
	0, 0, 0, 0, 0, 0, 0, 0, 93, 0,
	86, 82, 83, 84, 79, 80, 0, 0, 0, 0,
	0, 0, 87, 0, 0, 0, 0, 115, 85, 81,
	97, 0, 52, 0, 28, 10, 0, 0, 88, 91,
	54, 55, 56, 57, 58, 0, 0, 0, 0, 68,
	69, 0, 70, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 48, 49, 0, 0, 0,
	0, 50, 0, 51, 46, 47, 59, 60, 61, 62,
	63, 64, 65, 66, 0, 94, 0, 45, 0, 0,
	0, 0, 21, 0, 0, 0, 0, 0, 0, 41,
	77, 78, 32, 0, 90, 0, 23, 0, 0, 0,
	95, 22, 14, 13, 0, 15, 0, 26, 0, 27,
	0, 0, 16, 0, 0, 0, 17, 18, 31, 0,
	0, 19, 29, 0, 0, 30, 0, 0, 20, 0,
	25, 0, 53, 0, 0, 0, 0, 0, 0, 0,
	0, 93, 0, 86, 82, 83, 84, 79, 80, 0,
	0, 0, 0, 0, 0, 87, 0, 0, 0, 0,
	115, 85, 81, 97, 0, 52, 0, 28, 10, 137,
	136, 88, 91, 369, 370, 371, 372, 373, 0, 374,
	375, 376, 412, 413, 0, 0, 0, 0, 159, 0,
	160, 133, 134, 138, 140, 139, 152, 153, 150, 151,
	154, 155, 156, 157, 158, 148, 149, 142, 143, 141,
	144, 146, 147, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 377, 145, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 378,
	379, 0, 382, 383, 384, 363, 364, 365, 366, 367,
	368, 380, 381, 0, 0, 360, 0, 0, 0, 0,
	0, 0, 0, 0, 385, 386, 387, 388, 389, 390,
	391, 392, 393, 394, 395, 415, 416, 417, 418, 419,
	407, 408, 409, 410, 411, 396, 397, 398, 399, 400,
	401, 402, 403, 404, 405, 406, 0, 427, 425, 426,
	422, 423, 0, 414, 420, 421, 428, 429, 431, 430,
	432, 433, 369, 370, 371, 372, 373, 0, 374, 375,
	376, 412, 413, 424, 435, 434, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 377, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 378, 379,
	0, 382, 383, 384, 571, 572, 573, 570, 569, 568,
	380, 381, 0, 0, 747, 0, 0, 0, 0, 0,
	0, 0, 0, 385, 386, 387, 388, 389, 390, 391,
	392, 393, 394, 395, 415, 416, 417, 418, 419, 407,
	408, 409, 410, 411, 396, 397, 398, 399, 400, 401,
	402, 403, 404, 405, 406, 0, 427, 425, 426, 422,
	423, 0, 414, 420, 421, 428, 429, 431, 430, 432,
	433, 0, 0, 0, 0, 0, 54, 55, 56, 57,
	58, 0, 424, 435, 434, 68, 69, 0, 70, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 244,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 48, 49, 0, 0, 0, 0, 50, 0, 51,
	46, 47, 59, 60, 61, 62, 63, 64, 65, 66,
	0, 94, 0, 45, 0, 135, 137, 136, 120, 0,
	0, 0, 0, 0, 0, 0, 77, 78, 102, 0,
	90, 0, 0, 0, 0, 159, 95, 160, 133, 134,
	138, 140, 139, 152, 153, 150, 151, 154, 155, 156,
	157, 158, 148, 149, 142, 143, 141, 144, 146, 147,
	54, 55, 56, 57, 58, 0, 0, 0, 53, 68,
	69, 0, 70, 145, 0, 0, 245, 93, 0, 86,
	82, 83, 84, 79, 80, 0, 0, 0, 0, 0,
	0, 87, 0, 515, 0, 0, 115, 85, 81, 97,
	0, 52, 0, 0, 0, 48, 49, 88, 91, 0,
	0, 50, 0, 51, 46, 47, 59, 60, 61, 62,
	63, 64, 65, 66, 0, 94, 0, 45, 0, 0,
	0, 0, 120, 0, 0, 0, 0, 0, 0, 0,
	77, 78, 102, 0, 90, 0, 0, 0, 0, 0,
	95, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 511, 0,
	0, 0, 0, 0, 54, 55, 56, 57, 58, 0,
	0, 0, 53, 68, 69, 0, 70, 0, 0, 0,
	516, 93, 0, 86, 82, 83, 84, 79, 80, 0,
	0, 0, 0, 0, 0, 87, 0, 0, 0, 0,
	115, 85, 81, 97, 0, 52, 0, 0, 0, 48,
	49, 88, 91, 0, 0, 50, 0, 51, 46, 47,
	59, 60, 61, 62, 63, 64, 65, 66, 0, 94,
	0, 45, 0, 135, 137, 136, 120, 0, 0, 0,
	0, 0, 0, 0, 77, 78, 102, 446, 90, 0,
	0, 0, 0, 159, 95, 160, 133, 134, 138, 140,
	139, 152, 153, 150, 151, 154, 155, 156, 157, 158,
	148, 149, 142, 143, 141, 144, 146, 147, 54, 55,
	56, 57, 58, 0, 0, 0, 53, 68, 69, 0,
	70, 145, 0, 0, 0, 93, 0, 86, 82, 83,
	84, 79, 80, 0, 0, 0, 0, 0, 0, 87,
	0, 333, 0, 0, 115, 85, 81, 97, 0, 52,
	0, 0, 0, 48, 49, 88, 91, 0, 0, 50,
	0, 51, 46, 47, 59, 60, 61, 62, 63, 64,
	65, 66, 0, 94, 0, 45, 0, 0, 0, 0,
	120, 0, 0, 0, 0, 0, 0, 0, 77, 78,
	102, 0, 90, 0, 0, 0, 0, 0, 95, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 507, 0, 0, 0,
	0, 0, 54, 55, 56, 57, 58, 0, 0, 0,
	53, 68, 69, 0, 70, 0, 0, 0, 0, 93,
	0, 86, 82, 83, 84, 79, 80, 0, 0, 312,
	0, 0, 0, 87, 0, 0, 0, 0, 115, 85,
	81, 97, 0, 52, 0, 0, 0, 48, 49, 88,
	91, 0, 0, 50, 0, 51, 46, 47, 59, 60,
	61, 62, 63, 64, 65, 66, 0, 94, 0, 45,
	0, 135, 137, 136, 120, 0, 0, 0, 0, 0,
	0, 0, 77, 78, 102, 0, 90, 0, 0, 0,
	0, 159, 95, 160, 133, 134, 138, 140, 139, 152,
	153, 150, 151, 154, 155, 156, 157, 158, 148, 149,
	142, 143, 141, 144, 146, 147, 54, 55, 56, 57,
	58, 0, 0, 0, 53, 68, 69, 0, 70, 145,
	0, 0, 0, 93, 0, 86, 82, 83, 84, 79,
	80, 0, 0, 0, 0, 0, 0, 87, 0, 0,
	0, 0, 115, 85, 81, 97, 0, 52, 0, 0,
	0, 48, 49, 88, 91, 0, 483, 50, 0, 51,
	46, 47, 59, 60, 61, 62, 63, 64, 65, 66,
	0, 94, 0, 45, 0, 0, 0, 0, 120, 0,
	135, 137, 136, 0, 0, 0, 77, 78, 102, 0,
	90, 0, 0, 0, 0, 0, 95, 0, 0, 0,
	159, 681, 160, 133, 134, 138, 140, 139, 152, 153,
	150, 151, 154, 155, 156, 157, 158, 148, 149, 142,
	143, 141, 144, 146, 147, 0, 0, 0, 53, 0,
	0, 0, 0, 0, 0, 0, 0, 93, 145, 86,
	82, 83, 84, 79, 80, 0, 0, 0, 0, 0,
	0, 87, 135, 137, 136, 0, 115, 85, 81, 97,
	0, 52, 0, 0, 0, 0, 0, 88, 91, 0,
	0, 0, 159, 0, 160, 133, 134, 138, 140, 139,
	152, 153, 150, 151, 154, 155, 156, 157, 158, 148,
	149, 142, 143, 141, 144, 146, 147, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	145, 0, 135, 137, 136, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 682, 159, 0, 160, 133, 134, 138, 140, 139,
	152, 153, 150, 151, 154, 155, 156, 157, 158, 148,
	149, 142, 143, 141, 144, 146, 147, 135, 137, 136,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	145, 0, 0, 0, 0, 0, 0, 159, 0, 160,
	133, 134, 138, 140, 139, 152, 153, 150, 151, 154,
	155, 156, 157, 158, 148, 149, 142, 143, 141, 144,
	146, 147, 0, 322, 135, 137, 136, 0, 0, 0,
	0, 0, 0, 0, 0, 145, 0, 0, 0, 0,
	0, 0, 0, 0, 159, 0, 160, 133, 134, 138,
	140, 139, 152, 153, 150, 151, 154, 155, 156, 157,
	158, 148, 149, 142, 143, 141, 144, 146, 147, 0,
	135, 137, 136, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 145, 132, 0, 0, 0, 0, 0, 0,
	159, 0, 160, 133, 134, 138, 140, 139, 152, 153,
	150, 151, 154, 155, 156, 157, 158, 148, 149, 142,
	143, 141, 144, 146, 147, 135, 137, 136, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 594, 145, 0,
	0, 0, 0, 0, 0, 159, 0, 160, 133, 134,
	138, 140, 139, 152, 153, 150, 151, 154, 155, 156,
	157, 158, 148, 149, 142, 143, 141, 144, 146, 147,
	135, 137, 136, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 145, 575, 0, 0, 0, 0, 0,
	159, 0, 160, 133, 134, 138, 140, 139, 152, 153,
	150, 151, 154, 155, 156, 157, 158, 148, 149, 142,
	143, 141, 144, 146, 147, 135, 137, 136, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 145, 0,
	574, 0, 0, 0, 0, 159, 0, 160, 133, 134,
	138, 140, 139, 152, 153, 150, 151, 154, 155, 156,
	157, 158, 148, 149, 142, 143, 141, 144, 146, 147,
	135, 137, 136, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 145, 0, 499, 0, 0, 0, 0,
	159, 0, 160, 133, 134, 138, 140, 139, 152, 153,
	150, 151, 154, 155, 156, 157, 158, 148, 149, 142,
	143, 141, 144, 146, 147, 135, 137, 136, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 145, 0,
	498, 0, 0, 0, 0, 159, 0, 160, 133, 134,
	138, 140, 139, 152, 153, 150, 151, 154, 155, 156,
	157, 158, 148, 149, 142, 143, 141, 144, 146, 147,
	135, 137, 136, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 145, 0, 497, 0, 0, 0, 0,
	159, 0, 160, 133, 134, 138, 140, 139, 152, 153,
	150, 151, 154, 155, 156, 157, 158, 148, 149, 142,
	143, 141, 144, 146, 147, 135, 137, 136, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 145, 540,
	495, 0, 0, 0, 0, 159, 0, 160, 133, 134,
	138, 140, 139, 152, 153, 150, 151, 154, 155, 156,
	157, 158, 148, 149, 142, 143, 141, 144, 146, 147,
	0, 542, 0, 0, 0, 0, 0, 0, 120, 0,
	135, 137, 136, 145, 0, 474, 0, 0, 102, 0,
	90, 0, 0, 0, 0, 0, 95, 0, 0, 0,
	159, 479, 160, 133, 134, 138, 140, 139, 152, 153,
	150, 151, 154, 155, 156, 157, 158, 148, 149, 142,
	143, 141, 144, 146, 147, 0, 0, 0, 0, 0,
	470, 0, 0, 0, 0, 0, 541, 93, 145, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 115, 0, 0, 97,
	0, 199, 135, 137, 136, 0, 0, 453, 91, 0,
	0, 0, 0, 0, 0, 354, 0, 0, 0, 0,
	0, 0, 159, 0, 160, 133, 134, 138, 140, 139,
	152, 153, 150, 151, 154, 155, 156, 157, 158, 148,
	149, 142, 143, 141, 144, 146, 147, 135, 137, 136,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	145, 0, 0, 0, 0, 0, 0, 159, 0, 160,
	133, 134, 138, 140, 139, 152, 153, 150, 151, 154,
	155, 156, 157, 158, 148, 149, 142, 143, 141, 144,
	146, 147, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 145,
}
var yyPact = [...]int{

	-1000, -1000, 1512, -1000, -1000, -1000, -1000, 187, 41, 327,
	-1000, -1000, -1000, 186, 4446, 185, 184, 5462, 5462, 5462,
	-40, 398, 5462, -1000, 5662, 183, 182, 179, -1000, 7,
	5462, 429, 553, 500, 412, 426, 475, 499, 2341, -1000,
	-1000, 173, -1000, -1000, 313, 5462, 200, 200, 5462, 5462,
	5462, 5462, 5462, 167, 5462, 5462, 164, 5462, 5462, 5462,
	5462, 5462, 5462, 5462, 5462, 5462, 5462, -1000, 5462, 5462,
	5462, -1000, -1000, -1000, 249, 211, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, 377, 383, -1000,
	-1000, 9, -1000, 163, 4892, -1000, 196, 407, 136, 407,
	-46, -1000, -1000, 110, 365, 240, 305, 407, -1000, -1000,
	-1000, -1000, 3305, 5462, 370, 83, 5462, 5462, 106, 6297,
	-1000, 105, 102, 239, -1000, -1000, 238, -1000, 577, 237,
	-1000, 6297, -1000, 5462, 5462, 5462, 5462, 5462, 5462, 5462,
	5462, 5462, 5462, 5462, 5462, 5462, 5462, 5462, 5462, 5462,
	5462, 5462, 5462, 5462, 5462, 5462, 5462, 5462, 5462, 5348,
	5462, 200, 5462, 408, -1000, 5602, 101, -1000, 425, -1000,
	422, -1000, 6, 159, 4446, 157, 100, 550, 5234, 5462,
	5462, 5462, 5462, 5462, 5462, 5462, 5462, 5462, 5462, 5462,
	5462, -1000, -1000, 5462, 12, -1000, -1000, 208, 207, 5462,
	-1000, -1000, -1000, 456, 456, 456, 456, 6115, 5462, 6297,
	6297, 5462, 6297, 6297, 456, 456, 456, 456, 456, 456,
	456, 456, 898, 1660, 898, 763, 763, 381, -1000, 354,
	-1000, 374, 5120, 200, 79, 387, 5462, -1000, 4892, -85,
	616, -1000, -1000, 6252, 200, 150, 417, 196, 98, 196,
	-1000, -1000, 1349, -1000, 95, 236, 304, 407, -1000, 282,
	46, 416, 291, -1000, -1000, -1000, -1000, -1000, -1000, 6070,
	148, 93, 614, 6297, 6025, -1000, -1000, -1000, -1000, -40,
	-1000, 398, 5462, -1000, 5462, 1171, 1332, 4598, 898, 760,
	1495, 1980, 1818, 556, 556, 556, 456, 456, 456, 456,
	1040, 1040, 2138, 2138, 2138, 2138, 2138, 697, 697, 697,
	697, 6170, 5462, 1034, 613, -1000, -1000, 5411, 246, -1000,
	576, 3142, -1000, -1000, 145, -31, -1000, 5462, -1000, 5462,
	-1000, -1000, 898, 5462, 898, 898, 898, 898, 898, 898,
	898, 898, 898, 898, 898, 898, 5980, -1000, -1000, 5462,
	-1000, -40, -40, 5935, -1000, 5890, 5845, 5462, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, 514, 413, 5183, 30, -61, -1000, 4955,
	133, -1000, 4892, 5006, -1000, 4892, -1000, -1000, 1186, -1000,
	-1000, -1000, 43, 250, -1000, 407, 247, 378, -1000, 42,
	4283, 5462, 5462, 5462, 73, -1000, -1000, 6297, -1000, 5462,
	1034, 132, 200, 6102, 4120, 408, 5462, -1000, 309, -1000,
	137, 5800, 5754, 2979, 1980, 3957, 382, -1000, -1000, -1000,
	898, -89, -1000, -1000, 379, -1000, -1000, -1000, -1000, 5462,
	-1000, -1000, -1000, -1000, 6297, 200, 144, 129, -1000, 407,
	39, 597, -1000, -1000, 407, 378, -1000, -1000, -1000, 5707,
	92, 6297, -1000, 89, 82, 1034, 80, -1000, 243, -1000,
	200, 142, 4892, -1000, -1000, -1000, -1000, 6297, 341, 127,
	607, -1000, 505, -1000, -1000, 116, -1000, -1000, -1000, 10,
	-1000, -1000, 393, 364, 254, 580, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 4446, 545, 71, -1000, -1000, -1000,
	-1000, -1000, 337, -1000, 4892, -1000, 589, -1000, 407, -67,
	378, -1000, 597, 2816, 66, 5462, 1, -1000, 454, -1000,
	-1000, 3631, 6102, -1000, 4892, -119, 2653, -1000, 140, -49,
	535, 309, 193, -1000, -1000, -1000, 202, -1000, 574, 4609,
	500, 64, -1000, -1000, -1000, -1000, -1000, 3468, -69, 124,
	-70, 407, 589, -1000, -1000, -71, 63, -1000, 122, -1000,
	5462, 81, -1, 62, 444, -1000, -1000, -1000, 121, 118,
	-1000, 61, 254, -1000, -57, 309, -1000, 397, -1000, -1000,
	393, 5462, 201, -1000, 572, 4609, -1000, 254, -1000, 1041,
	3468, -1000, -1000, -1000, -1000, -83, -1000, -1000, 3794, 5530,
	-1000, -1000, -1000, -1000, -1000, 60, 2490, 3631, -1000, -1000,
	453, -1000, 2327, -1000, -1000, 570, -1000, 6297, -1000, 4609,
	5462, 139, -1000, -1000, 902, -1000, 59, 58, 328, 347,
	203, -1000, 83, -1000, -1000, -1000, -1000, -1000, -1000, 3468,
	-1000, 34, -1000, 114, 254, -1000, 2164, 5462, -1000, 6297,
	309, -1000, -1000, -1000, -1000, 254, 4748, 4609, 2001, 3468,
	-1000, -59, -1000, -1000, 6297, 112, 588, -1000, -1000, 4609,
	-1000, 15, -1000, 535, -1000, -1000, 1838, -78, -1000, -1000,
	-1000, -1000, 1675, -1000,
}
var yyPgo = [...]int{

	0, 544, 731, 730, 15, 5, 729, 2, 727, 197,
	30, 68, 24, 726, 1, 725, 38, 37, 724, 3,
	13, 22, 6, 721, 16, 0, 718, 716, 76, 85,
	715, 714, 711, 710, 708, 25, 706, 705, 704, 32,
	619, 702, 44, 697, 43, 696, 42, 694, 33, 17,
	26, 47, 693, 692, 11, 691, 35, 688, 687, 685,
	684, 36, 681, 680, 678, 4, 676, 12, 674, 9,
	671, 7, 670, 667, 8, 666, 664, 654, 653, 652,
	651, 479, 101, 650, 645, 74, 72, 644, 34, 643,
	640, 604, 635, 634, 28, 29, 460, 21, 57, 54,
	629, 14, 10,
}
var yyR1 = [...]int{

	0, 100, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 6,
	6, 6, 6, 6, 6, 6, 7, 7, 9, 9,
	10, 10, 10, 11, 11, 8, 8, 8, 8, 8,
	8, 8, 8, 8, 8, 8, 91, 91, 92, 92,
	93, 93, 94, 94, 95, 95, 96, 96, 97, 97,
	98, 98, 99, 99, 14, 14, 13, 13, 13, 12,
	12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
	12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
	12, 12, 12, 58, 58, 59, 59, 60, 60, 55,
	55, 56, 57, 57, 30, 30, 31, 31, 32, 32,
	33, 33, 34, 34, 35, 35, 36, 36, 38, 38,
	38, 38, 39, 39, 39, 102, 102, 37, 37, 49,
	49, 49, 49, 50, 51, 51, 52, 52, 53, 53,
	53, 53, 53, 53, 54, 54, 41, 41, 42, 43,
	43, 44, 44, 45, 45, 46, 47, 47, 48, 101,
	101, 16, 16, 15, 15, 1, 1, 61, 61, 62,
	62, 62, 62, 71, 71, 72, 72, 72, 73, 73,
	74, 74, 75, 76, 76, 76, 76, 77, 77, 78,
	79, 79, 63, 63, 68, 68, 69, 70, 70, 64,
	64, 65, 65, 65, 65, 65, 65, 66, 66, 67,
	67, 17, 22, 22, 23, 23, 24, 24, 18, 18,
	4, 4, 2, 2, 3, 3, 20, 20, 21, 21,
	21, 19, 19, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 80, 80, 80, 80,
	80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	80, 80, 81, 81, 81, 81, 82, 82, 82, 82,
	82, 82, 82, 83, 83, 83, 83, 84, 84, 84,
	85, 85, 86, 87, 87, 87, 88, 88, 88, 25,
	25, 40, 40, 27, 28, 28, 28, 90, 90, 90,
	29, 29, 29, 89, 89,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 3,
	1, 2, 3, 2, 0, 1, 1, 1, 4, 3,
	5, 4, 3, 4, 3, 4, 1, 1, 6, 7,
	6, 7, 3, 1, 3, 1, 3, 1, 1, 2,
	1, 3, 1, 2, 2, 0, 1, 1, 1, 3,
	1, 1, 5, 7, 9, 5, 3, 3, 3, 3,
	3, 3, 1, 2, 6, 7, 9, 5, 1, 6,
	3, 3, 2, 0, 9, 1, 3, 0, 4, 3,
	1, 3, 1, 4, 5, 6, 1, 3, 6, 7,
	3, 6, 1, 4, 0, 1, 3, 1, 3, 4,
	4, 5, 0, 5, 4, 1, 1, 1, 4, 1,
	2, 4, 3, 1, 0, 1, 3, 1, 3, 1,
	4, 2, 6, 4, 1, 4, 3, 1, 1, 3,
	1, 1, 3, 3, 1, 1, 1, 3, 1, 0,
	1, 6, 5, 1, 2, 1, 1, 2, 0, 3,
	4, 3, 9, 1, 3, 1, 2, 3, 1, 2,
	2, 2, 3, 3, 3, 4, 3, 1, 1, 3,
	1, 3, 1, 1, 3, 1, 3, 0, 1, 1,
	2, 1, 1, 1, 1, 1, 1, 3, 1, 1,
	3, 10, 1, 0, 1, 3, 4, 6, 0, 1,
	0, 1, 0, 1, 0, 1, 1, 2, 1, 1,
	1, 0, 2, 3, 4, 2, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 2, 2,
	2, 2, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 2,
	2, 2, 2, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 5, 4, 3, 4, 2, 2, 4,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	1, 2, 1, 2, 4, 2, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 3, 2, 3, 3,
	1, 1, 2, 2, 1, 2, 1, 4, 3, 3,
	3, 6, 3, 1, 1, 2, 1, 1, 3, 3,
	1, 1, 1, 1, 3, 1, 4, 3, 1, 1,
	1, 0, 1, 1, 1, 1, 3, 1, 3, 1,
	1, 4, 2, 3, 3,
}
var yyChk = [...]int{

	-1000, -100, -11, -8, -12, -17, -16, 127, 154, 120,
	162, -31, -33, 97, 96, 99, 106, 110, 111, 115,
	122, 76, 95, 90, -25, 124, 101, 103, 161, 116,
	119, 112, 86, 113, -15, 128, -30, -32, -28, -26,
	-1, 83, -27, -89, -87, 71, 58, 59, 49, 50,
	55, 57, 159, 126, 4, 5, 6, 7, 8, 60,
	61, 62, 63, 64, 65, 66, 67, -80, 13, 14,
	16, 77, 78, -29, -85, -86, -88, 84, 85, 141,
	142, 156, 138, 139, 140, 155, 137, 149, 165, -84,
	88, 166, -10, 135, 69, 94, -9, 157, 159, 157,
	-9, 162, 86, -93, -91, -96, -9, 157, 113, 114,
	-99, -98, -14, 159, -12, 154, 159, 159, -40, -25,
	76, -40, -40, -41, -42, -29, -43, -44, 88, -45,
	-46, -25, 161, 33, 34, 10, 12, 11, 35, 37,
	36, 51, 49, 50, 52, 68, 53, 54, 47, 48,
	40, 41, 38, 39, 42, 43, 44, 45, 46, 30,
	32, 159, 159, 159, 162, -25, 86, 31, -4, 37,
	128, -1, 86, 73, 74, 73, 75, 74, 17, 18,
	19, 20, 29, 21, 22, 23, 24, 25, 26, 27,
	28, 58, 59, 159, 133, -25, -28, -85, -86, 159,
	-88, -10, -28, -25, -25, -25, -25, -25, 159, -25,
	-25, 159, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, 153, 153, 93, 150, -81,
	-82, 88, 151, 152, -81, 93, 162, -29, 159, -50,
	-52, -51, -53, -25, 37, 134, 157, -9, 160, -9,
	161, 162, -11, 161, -92, -96, -9, 157, 161, 9,
	157, 105, -9, -98, -13, 163, -12, -17, -16, -25,
	97, -35, -36, -25, -25, 161, 161, 161, 161, 9,
	161, 9, 17, 161, 9, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, 31, -25, -47, -48, -28, -25, -55, -56,
	86, -14, 161, 161, 86, 86, 162, 159, -12, 159,
	161, 31, -25, 37, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -90, 86, 162,
	-29, 153, 153, -25, 160, -25, -25, 15, -7, -29,
	86, -6, -5, 76, 77, 78, 79, 80, 81, 4,
	5, 6, 7, 8, 10, 11, 12, 56, 70, 71,
	82, 83, 73, 74, 75, 95, 96, 97, 98, 99,
	100, 101, 102, 103, 104, 105, 116, 117, 118, 119,
	120, 121, 122, 123, 124, 125, 126, 111, 112, 113,
	114, 115, 13, 14, 134, 106, 107, 108, 109, 110,
	135, 136, 131, 132, 154, 129, 130, 128, 137, 138,
	140, 139, 141, 142, 156, 155, -7, -29, 150, -82,
	150, -82, 93, 69, 133, -25, 87, -28, 165, -25,
	-50, 164, 9, 15, -28, 159, 86, 161, -11, 163,
	161, 161, 157, -9, -99, 157, -9, 162, 86, 157,
	160, 159, 161, 9, 160, -42, -44, -25, -46, 31,
	-25, -101, 9, 105, 160, 9, 17, 163, 159, 162,
	-61, -25, -25, -14, -25, 160, -25, 160, 160, 160,
	-25, -83, 86, 89, 50, 88, 86, 163, 163, 69,
	163, 163, 160, -51, -25, 37, 134, -50, 163, 162,
	157, -94, -97, -98, -91, 162, -34, -12, 31, -25,
	-35, -25, -38, 162, 31, -25, 160, -48, -49, -28,
	37, 134, 69, -57, -12, 31, -56, -25, -58, -22,
	-23, -24, -18, -20, -21, 30, -10, 135, 136, -61,
	163, -62, -63, -70, 120, -64, 123, -65, 81, 80,
	79, 76, 77, 78, 160, 160, 75, -12, 31, 163,
	164, 89, -25, -28, 159, 160, -95, -98, 162, -101,
	9, -98, -94, -14, 160, 161, -39, 161, -39, 161,
	161, 160, 15, -28, 159, -50, -14, -60, 117, 118,
	160, 9, -2, 37, -21, 163, -66, -67, 88, 114,
	113, -71, -10, -65, -12, 31, 161, -14, 164, -50,
	-101, 9, -95, 163, -97, -101, 98, 161, -35, 163,
	108, 109, -39, 107, -39, -54, -12, 31, -49, -50,
	164, 104, 159, 162, -19, 31, -24, -3, 158, 161,
	9, 17, -68, -69, -7, -4, -72, 9, 161, 162,
	-14, 163, 160, 163, -98, -101, 163, 161, 160, -25,
	-102, 31, 161, 163, 161, 107, -14, 160, 160, 161,
	-59, -10, -14, 162, -20, 88, -67, -25, 161, 9,
	17, -7, -10, 163, -73, -74, -75, -76, -78, -77,
	-10, -7, 154, 86, 163, -37, -12, 31, -102, -14,
	161, 102, -54, 88, 35, 163, -14, 17, -69, -25,
	159, 163, -74, 161, 161, 121, 105, 153, -14, -14,
	161, 160, -10, 163, -25, -22, -71, 86, -5, -65,
	-7, 100, 162, 160, -7, 161, -14, -19, 163, -79,
	161, 162, -14, 163,
}
var yyDef = [...]int{

	84, -2, 1, 83, 85, 86, 87, 0, 0, 0,
	115, 120, 121, 0, 0, 0, 0, 401, 401, 401,
	0, 390, 0, 132, 0, 0, 0, 0, 138, 0,
	0, 0, 78, 270, 0, 0, 156, 0, -2, 400,
	213, 0, 404, 405, 392, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 350, 0, 352,
	0, 215, 216, 403, 0, 0, -2, 356, 357, 358,
	359, 360, 361, 362, 363, 364, 365, 0, 0, 371,
	410, 0, -2, 0, 184, 398, 80, 0, 0, 0,
	0, 84, 78, 0, 0, 0, 110, 0, 96, 97,
	107, 112, 0, 0, 0, 0, 164, 0, 0, 402,
	390, 0, 0, 0, 197, 198, 0, 200, 201, 0,
	204, 205, 133, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 115, 0, 0, 142, 0, 271,
	0, 214, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 298, 300, 0, 0, 285, -2, 0, 0, 0,
	395, 391, -2, 319, 320, 321, 322, 0, 0, 337,
	338, 0, 340, 341, 342, 343, 344, 345, 346, 347,
	348, 349, 351, 353, 355, 0, 0, 0, 367, 0,
	374, 376, 0, 0, 0, 0, 0, 412, 184, 0,
	183, 187, 185, 189, 0, 0, 0, 81, 0, 82,
	89, 84, 0, 92, 0, 0, 110, 0, 94, 0,
	0, 0, 110, 113, 114, 119, 116, 117, 118, 0,
	0, 0, 165, 167, 0, 126, 127, 128, 129, 0,
	130, 0, 0, 131, 0, 302, 303, 304, 305, 306,
	307, 308, 309, 310, 311, 312, 313, 314, 315, 316,
	317, 318, -2, -2, -2, -2, -2, -2, -2, -2,
	-2, 0, 0, 335, 209, 206, -2, 0, 0, 150,
	0, 0, 140, 141, 0, 0, 218, 0, 157, 0,
	160, 115, 283, 0, 286, 287, 288, 289, 290, 291,
	292, 293, 294, 295, 296, 297, 0, 406, 407, 0,
	409, 0, 0, 0, -2, 0, 0, 0, 388, 413,
	76, 77, 69, 70, 71, 72, 73, 74, 75, 2,
	3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
	13, 14, 15, 16, 17, 18, 19, 20, 21, 22,
	23, 24, 25, 26, 27, 28, 29, 30, 31, 32,
	33, 34, 35, 36, 37, 38, 39, 40, 41, 42,
	43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
	53, 54, 55, 56, 57, 58, 59, 60, 61, 62,
	63, 64, 65, 66, 67, 68, 389, 414, 366, 375,
	369, 372, 373, 0, 0, 0, 0, 393, 368, 0,
	0, 397, 184, 0, -2, 184, 79, 88, 0, 91,
	93, 95, 0, 110, 106, 0, 110, 0, 111, 0,
	0, 0, 164, 0, 0, 196, 199, 202, 203, 0,
	334, 0, 210, 0, 0, 0, 0, 143, -2, 218,
	247, 0, 0, 0, 284, 0, 0, 394, 336, 339,
	354, 0, 383, 384, 0, 386, 378, 379, 380, 0,
	382, 411, 396, 186, 188, 0, 0, 0, 90, 0,
	0, 209, 103, 108, 0, 0, 122, 162, 115, 0,
	0, 166, 125, 172, 172, 333, 0, 207, 0, -2,
	0, 0, 184, 137, 152, 115, 149, 151, 147, 0,
	262, 264, 272, 269, 276, 0, 278, 279, 280, 247,
	212, 217, 0, 0, 0, -2, 243, 249, 251, 252,
	253, 254, 255, 256, 0, 0, 0, 154, 115, 408,
	377, 385, 0, -2, 184, 193, 209, 105, 0, 0,
	210, 109, 209, 0, 0, 164, 0, 172, 0, 172,
	134, 0, 0, -2, 184, 0, 0, 139, 0, 0,
	281, 268, 274, 273, 277, 211, 0, 258, 259, 0,
	270, 0, 223, 250, 155, 115, 161, 158, 0, 0,
	0, 210, 209, 100, 102, 0, 0, 123, 0, 168,
	0, 0, 0, 0, 0, 135, 194, 115, 0, 0,
	-2, 0, 0, 115, 0, 0, 265, 0, 275, 219,
	0, 0, 0, 245, 0, 0, 221, 0, 225, 0,
	159, 381, 192, 98, 104, 0, 101, 163, 0, 0,
	115, 175, 176, 169, 170, 0, 0, 0, 181, 153,
	0, 145, 0, 115, 282, 266, 257, 260, 220, 0,
	0, 0, 224, 226, 0, 228, 0, 0, 238, 0,
	0, 237, 57, -2, 99, 124, 177, 115, 115, 174,
	171, 0, 136, 0, 0, 148, 0, 0, 244, 246,
	-2, 227, 229, 230, 231, 0, 0, 0, 0, 173,
	195, 0, 146, 261, 267, 0, 232, 233, 234, 236,
	239, 0, 115, 281, 235, 178, 0, 0, 144, 222,
	240, 115, 0, 241,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 55, 165, 3, 166, 54, 37, 3,
	159, 160, 52, 49, 9, 50, 51, 53, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 31, 161,
	43, 17, 45, 30, 67, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 69, 3, 164, 36, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 162, 35, 163, 57,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 10, 11, 12,
	13, 14, 15, 16, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 32, 33, 34, 38,
	39, 40, 41, 42, 44, 46, 47, 48, 56, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 68, 70,
	71, 72, 73, 74, 75, 76, 77, 78, 79, 80,
	81, 82, 83, 84, 85, 86, 87, 88, 89, 90,
	91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
	111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128, 129, 130,
	131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
	141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
	151, 152, 153, 154, 155, 156, 157, 158,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:298
		{
			fmt.Println(yyDollar[1].node)
		}
	case 2:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:302
		{
			yyVAL.value = yyDollar[1].token
		}
	case 3:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:302
		{
			yyVAL.value = yyDollar[1].token
		}
	case 4:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:302
		{
			yyVAL.value = yyDollar[1].token
		}
	case 5:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:302
		{
			yyVAL.value = yyDollar[1].token
		}
	case 6:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:302
		{
			yyVAL.value = yyDollar[1].token
		}
	case 7:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:302
		{
			yyVAL.value = yyDollar[1].token
		}
	case 8:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:302
		{
			yyVAL.value = yyDollar[1].token
		}
	case 9:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:302
		{
			yyVAL.value = yyDollar[1].token
		}
	case 10:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 11:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 12:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 13:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 14:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 15:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 16:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 17:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 18:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 19:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 20:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 21:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 22:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 23:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 24:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 25:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 26:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 27:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 28:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 29:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 30:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 31:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 32:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 33:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 34:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 35:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 36:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 37:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 38:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 39:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 40:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 41:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 42:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 43:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 44:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 45:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 46:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 47:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 48:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 49:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 50:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 51:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 52:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 53:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 54:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 55:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 56:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 57:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 58:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 59:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 60:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 61:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 62:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 63:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 64:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 65:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 66:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 67:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 68:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 69:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:312
		{
			yyVAL.value = yyDollar[1].value
		}
	case 70:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 71:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 72:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 73:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 74:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 75:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].token
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			yyVAL.node = Node("identifier").attribute("value", yyDollar[1].token)
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:318
		{
			yyVAL.node = Node("identifier").attribute("value", yyDollar[1].value)
		}
	case 78:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.node = Node("NamespaceParts").append(Node(yyDollar[1].token))
		}
	case 79:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:323
		{
			yyVAL.node = yyDollar[1].node.append(Node(yyDollar[3].token))
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.node = Node("Name").append(yyDollar[1].node)
		}
	case 81:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:328
		{
			yyVAL.node = Node("Name").append(yyDollar[2].node).attribute("FullyQualified", "true")
		}
	case 82:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:329
		{
			yyVAL.node = Node("Name").append(yyDollar[3].node).attribute("Relative", "true")
		}
	case 83:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:333
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 84:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:334
		{
			yyVAL.node = Node("Statements")
		}
	case 85:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:338
		{
			yyVAL.node = yyDollar[1].node
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:339
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:340
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:342
		{
			yyVAL.node = Node("THaltCompiler")
		}
	case 89:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:344
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node)
		}
	case 90:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:346
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 91:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:347
		{
			yyVAL.node = Node("Namespace").append(yyDollar[3].node)
		}
	case 92:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:348
		{
			yyVAL.node = yyDollar[2].node
		}
	case 93:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:349
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[2].node)
		}
	case 94:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:350
		{
			yyVAL.node = yyDollar[2].node
		}
	case 95:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:351
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[2].node)
		}
	case 96:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:355
		{
			yyVAL.node = Node("FuncUseType")
		}
	case 97:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:356
		{
			yyVAL.node = Node("ConstUseType")
		}
	case 98:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:361
		{
			yyVAL.node = Node("GroupUse").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 99:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:363
		{
			yyVAL.node = Node("GroupUse").append(yyDollar[2].node).append(yyDollar[5].node)
		}
	case 100:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:368
		{
			yyVAL.node = Node("MixedGroupUse").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 101:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:370
		{
			yyVAL.node = Node("MixedGroupUse").append(yyDollar[2].node).append(yyDollar[5].node)
		}
	case 102:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:375
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 103:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:376
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 104:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:380
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 105:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:381
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 106:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:384
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 107:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:385
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 108:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:388
		{
			yyVAL.node = yyDollar[1].node
		}
	case 109:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:389
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 110:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:392
		{
			yyVAL.node = Node("UseElem").append(yyDollar[1].node)
		}
	case 111:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:393
		{
			yyVAL.node = Node("UseElem").append(yyDollar[1].node).append(Node("as").attribute("value", yyDollar[3].token))
		}
	case 112:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:396
		{
			yyVAL.node = yyDollar[1].node
		}
	case 113:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:397
		{
			yyVAL.node = yyDollar[2].node
		}
	case 114:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:401
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 115:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:402
		{
			yyVAL.node = Node("stmt")
		}
	case 116:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:406
		{
			yyVAL.node = yyDollar[1].node
		}
	case 117:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:407
		{
			yyVAL.node = yyDollar[1].node
		}
	case 118:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:408
		{
			yyVAL.node = yyDollar[1].node
		}
	case 119:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:411
		{
			yyVAL.node = yyDollar[2].node
		}
	case 120:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:412
		{
			yyVAL.node = yyDollar[1].node
		}
	case 121:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:413
		{
			yyVAL.node = yyDollar[1].node
		}
	case 122:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:415
		{
			yyVAL.node = Node("While").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("stmt").append(yyDollar[5].node))
		}
	case 123:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:421
		{
			yyVAL.node = Node("DoWhile").
				append(Node("expr").append(yyDollar[5].node)).
				append(Node("stmt").append(yyDollar[2].node))
		}
	case 124:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:427
		{
			yyVAL.node = Node("For").
				append(Node("expr1").append(yyDollar[3].node)).
				append(Node("expr2").append(yyDollar[5].node)).
				append(Node("expr3").append(yyDollar[7].node)).
				append(Node("stmt").append(yyDollar[9].node))
		}
	case 125:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:434
		{
			yyVAL.node = Node("Switch").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node)
		}
	case 126:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:435
		{
			yyVAL.node = Node("Break").append(yyDollar[2].node)
		}
	case 127:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:436
		{
			yyVAL.node = Node("Continue").append(yyDollar[2].node)
		}
	case 128:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:437
		{
			yyVAL.node = Node("Return").append(yyDollar[2].node)
		}
	case 129:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:438
		{
			yyVAL.node = yyDollar[2].node
		}
	case 130:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:439
		{
			yyVAL.node = yyDollar[2].node
		}
	case 131:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:440
		{
			yyVAL.node = yyDollar[2].node
		}
	case 132:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:441
		{
			yyVAL.node = Node("Echo").append(Node("InlineHtml").attribute("value", yyDollar[1].token))
		}
	case 133:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:442
		{
			yyVAL.node = yyDollar[1].node
		}
	case 134:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:444
		{
			yyVAL.node = Node("Unset").append(yyDollar[3].node)
		}
	case 135:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:446
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachVariable").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 136:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:453
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachKey").append(yyDollar[5].node)).
				append(Node("ForeachVariable").append(yyDollar[7].node)).
				append(yyDollar[9].node)
		}
	case 137:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:460
		{
			yyVAL.node = Node("Declare").append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 138:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:461
		{
			yyVAL.node = Node("")
		}
	case 139:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:463
		{
			yyVAL.node = Node("Try").
				append(yyDollar[3].node).
				append(yyDollar[5].node).
				append(yyDollar[6].node)
		}
	case 140:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:469
		{
			yyVAL.node = Node("Throw").append(yyDollar[2].node)
		}
	case 141:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:470
		{
			yyVAL.node = Node("GoTo").attribute("Label", yyDollar[2].token)
		}
	case 142:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:471
		{
			yyVAL.node = Node("Label").attribute("name", yyDollar[1].token)
		}
	case 143:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:474
		{
			yyVAL.node = Node("CatchList")
		}
	case 144:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:476
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[4].node).append(Node("Variable").attribute("name", yyDollar[5].token)).append(yyDollar[8].node)
		}
	case 145:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:479
		{
			yyVAL.node = Node("CatchNameList").append(yyDollar[1].node)
		}
	case 146:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:480
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 147:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:484
		{
			yyVAL.node = Node("")
		}
	case 148:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:485
		{
			yyVAL.node = Node("Finnaly").append(yyDollar[3].node)
		}
	case 149:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:489
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 150:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:490
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 151:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:494
		{
			yyVAL.node = Node("Const").attribute("name", yyDollar[1].token).append(yyDollar[3].node)
		}
	case 152:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:498
		{
			yyVAL.node = yyDollar[1].node
		}
	case 153:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:499
		{
			yyVAL.node = yyDollar[2].node
		}
	case 154:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:504
		{
			yyVAL.node = Node("If").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[5].node))
		}
	case 155:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:508
		{
			yyVAL.node = yyDollar[1].node.append(Node("ElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[6].node)))
		}
	case 156:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:514
		{
			yyVAL.node = yyDollar[1].node
		}
	case 157:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:516
		{
			yyVAL.node = yyDollar[1].node.append(Node("Else").append(Node("stmt").append(yyDollar[3].node)))
		}
	case 158:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:523
		{
			yyVAL.node = Node("AltIf").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[6].node))
		}
	case 159:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:527
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[7].node)))
		}
	case 160:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:533
		{
			yyVAL.node = yyDollar[1].node
		}
	case 161:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:535
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElse").append(Node("stmt").append(yyDollar[4].node)))
		}
	case 162:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:541
		{
			yyVAL.node = yyDollar[1].node
		}
	case 163:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:542
		{
			yyVAL.node = yyDollar[2].node
		}
	case 164:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:546
		{
			yyVAL.node = Node("")
		}
	case 165:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:547
		{
			yyVAL.node = yyDollar[1].node
		}
	case 166:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:550
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 167:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:551
		{
			yyVAL.node = Node("ExpressionList").append(yyDollar[1].node)
		}
	case 168:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:555
		{
			yyVAL.node = yyDollar[2].node
		}
	case 169:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:556
		{
			yyVAL.node = yyDollar[3].node
		}
	case 170:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:557
		{
			yyVAL.node = yyDollar[2].node
		}
	case 171:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:558
		{
			yyVAL.node = yyDollar[3].node
		}
	case 172:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:562
		{
			yyVAL.node = Node("CaseList")
		}
	case 173:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:564
		{
			yyVAL.node = yyDollar[1].node.append(Node("Case").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node))
		}
	case 174:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:568
		{
			yyVAL.node = yyDollar[1].node.append(Node("Default").append(yyDollar[4].node))
		}
	case 177:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:579
		{
			yyVAL.node = yyDollar[1].node
		}
	case 178:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:580
		{
			yyVAL.node = yyDollar[2].node
		}
	case 179:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:584
		{
			yyVAL.node = yyDollar[1].node
		}
	case 180:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:585
		{
			yyVAL.node = Node("Ref").append(yyDollar[2].node)
		}
	case 181:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:586
		{
			yyVAL.node = Node("List").append(yyDollar[3].node)
		}
	case 182:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:587
		{
			yyVAL.node = Node("ShortList").append(yyDollar[2].node)
		}
	case 183:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:591
		{ /* TODO: allow single trailing comma */
			yyVAL.node = yyDollar[1].node
		}
	case 184:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:595
		{
			yyVAL.node = Node("")
		}
	case 185:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:596
		{
			yyVAL.node = yyDollar[1].node
		}
	case 186:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:601
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 187:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:602
		{
			yyVAL.node = Node("ArrayPairList").append(yyDollar[1].node)
		}
	case 188:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:606
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 189:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:607
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node)
		}
	case 190:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:608
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(Node("Ref").append(yyDollar[4].node))
		}
	case 191:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:609
		{
			yyVAL.node = Node("ArrayElement").append(Node("Ref").append(yyDollar[2].node))
		}
	case 192:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:611
		{
			yyVAL.node = Node("ArrayElement").
				append(yyDollar[1].node).
				append(Node("ArrayList").append(yyDollar[5].node))
		}
	case 193:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:617
		{
			yyVAL.node = Node("ArrayElement").
				append(Node("ArrayList").append(yyDollar[3].node))
		}
	case 194:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:624
		{
			yyVAL.node = yyDollar[1].node
		}
	case 195:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:625
		{
			yyVAL.node = yyDollar[2].node
		}
	case 196:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:629
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 197:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:630
		{
			yyVAL.node = Node("GlobalVarList").append(yyDollar[1].node)
		}
	case 198:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:634
		{
			yyVAL.node = yyDollar[1].node
		}
	case 199:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:638
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 200:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:639
		{
			yyVAL.node = Node("StaticVarList").append(yyDollar[1].node)
		}
	case 201:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:643
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token)
		}
	case 202:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:644
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token).append(Node("expr").append(yyDollar[3].node))
		}
	case 203:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:648
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 204:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:649
		{
			yyVAL.node = Node("EchoList").append(yyDollar[1].node)
		}
	case 205:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:653
		{
			yyVAL.node = Node("Echo").append(yyDollar[1].node)
		}
	case 206:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:657
		{
			yyVAL.node = Node("UnsetVariablesList").append(yyDollar[1].node)
		}
	case 207:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:658
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 208:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:662
		{
			yyVAL.node = yyDollar[1].node
		}
	case 211:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:672
		{
			yyVAL.node = yyDollar[1].node.attribute("name", yyDollar[3].token).append(yyDollar[5].node)
		}
	case 212:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:673
		{
			yyVAL.node = Node("Class").attribute("name", yyDollar[2].token).append(yyDollar[4].node)
		}
	case 213:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:677
		{
			yyVAL.node = Node("Class").attribute(yyDollar[1].value, "true")
		}
	case 214:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:678
		{
			yyVAL.node = yyDollar[1].node.attribute(yyDollar[2].value, "true")
		}
	case 215:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:682
		{
			yyVAL.value = "abstract"
		}
	case 216:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:683
		{
			yyVAL.value = "final"
		}
	case 217:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:687
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 218:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:688
		{
			yyVAL.node = Node("Stmt")
		}
	case 219:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:692
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 220:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:693
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[1].node)
		}
	case 221:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:694
		{
			yyVAL.node = Node("Use").append(yyDollar[2].node).append(yyDollar[3].node)
		}
	case 222:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:697
		{
			yyVAL.node = Node("Function").
				append(yyDollar[1].node).
				append(Node("name").append(yyDollar[4].node)).
				attribute("returns_ref", yyDollar[3].value).
				append(yyDollar[6].node).
				append(yyDollar[8].node).
				append(yyDollar[9].node)
		}
	case 223:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:709
		{
			yyVAL.node = Node("NameList").append(yyDollar[1].node)
		}
	case 224:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:710
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 225:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:714
		{
			yyVAL.node = Node("")
		}
	case 226:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:715
		{
			yyVAL.node = Node("")
		}
	case 227:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:716
		{
			yyVAL.node = yyDollar[2].node
		}
	case 228:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:720
		{
			yyVAL.node = Node("TraitAdaptionList").append(yyDollar[1].node)
		}
	case 229:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:721
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 230:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:725
		{
			yyVAL.node = yyDollar[1].node
		}
	case 231:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:726
		{
			yyVAL.node = yyDollar[1].node
		}
	case 232:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:731
		{
			yyVAL.node = Node("TraitPrecedence").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 233:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:735
		{
			yyVAL.node = yyDollar[1].node.append(Node("as").attribute("value", yyDollar[3].token))
		}
	case 234:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:737
		{
			yyVAL.node = yyDollar[1].node.append(Node("as").append(Node("reservedNonModifiers")))
		}
	case 235:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:739
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 236:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:740
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 237:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:743
		{
			yyVAL.node = Node("TraitMethodRef").append(yyDollar[1].node)
		}
	case 238:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:744
		{
			yyVAL.node = yyDollar[1].node
		}
	case 239:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:748
		{
			yyVAL.node = Node("TraitMethodRef").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 240:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:752
		{
			yyVAL.node = Node("")
		}
	case 241:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:753
		{
			yyVAL.node = yyDollar[2].node
		}
	case 242:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:757
		{
			yyVAL.node = yyDollar[1].node
		}
	case 243:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:758
		{
			yyVAL.node = Node("VarMemberModifier")
		}
	case 244:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:762
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 245:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:763
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:767
		{
			yyVAL.node = Node("Const").append(yyDollar[3].node)
		}
	case 247:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:771
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 248:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:772
		{
			yyVAL.node = yyDollar[1].node
		}
	case 249:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:775
		{
			yyVAL.node = yyDollar[1].node
		}
	case 250:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:776
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 251:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:779
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 252:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:780
		{
			yyVAL.node = Node("ProtectedMemberModifier")
		}
	case 253:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:781
		{
			yyVAL.node = Node("PrivateMemberModifier")
		}
	case 254:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:782
		{
			yyVAL.node = Node("StaticMemberModifier")
		}
	case 255:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:783
		{
			yyVAL.node = Node("AbstractMemberModifier")
		}
	case 256:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:784
		{
			yyVAL.node = Node("FinalMemberModifier")
		}
	case 257:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:788
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 258:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:789
		{
			yyVAL.node = Node("PropertyList").append(yyDollar[1].node)
		}
	case 259:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:792
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token)
		}
	case 260:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:793
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token).append(Node("Default").append(yyDollar[3].node))
		}
	case 261:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser.y:798
		{
			yyVAL.node = Node("Function").
				attribute("name", yyDollar[3].token).
				attribute("returns_ref", yyDollar[2].value).
				append(yyDollar[5].node).
				append(yyDollar[7].node).
				append(yyDollar[9].node)
		}
	case 262:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:809
		{
			yyVAL.node = yyDollar[1].node
		}
	case 263:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:810
		{
			yyVAL.node = Node("Parameter list")
		}
	case 264:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:813
		{
			yyVAL.node = Node("Parameter list").append(yyDollar[1].node)
		}
	case 265:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:814
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 266:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:818
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token)
		}
	case 267:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:826
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token).
				append(yyDollar[6].node)
		}
	case 268:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:837
		{
			yyVAL.node = Node("No type")
		}
	case 269:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:838
		{
			yyVAL.node = yyDollar[1].node
		}
	case 270:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:842
		{
			yyVAL.value = "false"
		}
	case 271:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:843
		{
			yyVAL.value = "true"
		}
	case 272:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:847
		{
			yyVAL.value = "false"
		}
	case 273:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:848
		{
			yyVAL.value = "true"
		}
	case 274:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:852
		{
			yyVAL.value = "false"
		}
	case 275:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:853
		{
			yyVAL.value = "true"
		}
	case 276:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:857
		{
			yyVAL.node = yyDollar[1].node
		}
	case 277:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:858
		{
			yyVAL.node = yyDollar[2].node
			yyVAL.node.attribute("nullable", "true")
		}
	case 278:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:862
		{
			yyVAL.node = yyDollar[1].node
		}
	case 279:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:863
		{
			yyVAL.node = Node("array type")
		}
	case 280:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:864
		{
			yyVAL.node = Node("callable type")
		}
	case 281:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:868
		{
			yyVAL.node = Node("void")
		}
	case 282:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:869
		{
			yyVAL.node = yyDollar[2].node
		}
	case 283:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:873
		{
			yyVAL.node = Node("Assign").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 284:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:874
		{
			yyVAL.node = Node("AssignRef").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 285:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:875
		{
			yyVAL.node = Node("Clone").append(yyDollar[2].node)
		}
	case 286:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:876
		{
			yyVAL.node = Node("AssignAdd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 287:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:877
		{
			yyVAL.node = Node("AssignSub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 288:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:878
		{
			yyVAL.node = Node("AssignMul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 289:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:879
		{
			yyVAL.node = Node("AssignPow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 290:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:880
		{
			yyVAL.node = Node("AssignDiv").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 291:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:881
		{
			yyVAL.node = Node("AssignConcat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 292:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:882
		{
			yyVAL.node = Node("AssignMod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 293:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:883
		{
			yyVAL.node = Node("AssignAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 294:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:884
		{
			yyVAL.node = Node("AssignOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 295:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:885
		{
			yyVAL.node = Node("AssignXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 296:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:886
		{
			yyVAL.node = Node("AssignShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 297:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:887
		{
			yyVAL.node = Node("AssignShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 298:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:888
		{
			yyVAL.node = Node("PostIncrement").append(yyDollar[1].node)
		}
	case 299:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:889
		{
			yyVAL.node = Node("PreIncrement").append(yyDollar[2].node)
		}
	case 300:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:890
		{
			yyVAL.node = Node("PostDecrement").append(yyDollar[1].node)
		}
	case 301:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:891
		{
			yyVAL.node = Node("PreDecrement").append(yyDollar[2].node)
		}
	case 302:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:892
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 303:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:893
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 304:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:894
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 305:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:895
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 306:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:896
		{
			yyVAL.node = Node("Xor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 307:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:897
		{
			yyVAL.node = Node("BitwiseOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 308:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:898
		{
			yyVAL.node = Node("BitwiseAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 309:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:899
		{
			yyVAL.node = Node("BitwiseXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 310:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:900
		{
			yyVAL.node = Node("Concat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 311:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:901
		{
			yyVAL.node = Node("Add").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 312:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:902
		{
			yyVAL.node = Node("Sub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 313:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:903
		{
			yyVAL.node = Node("Mul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 314:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:904
		{
			yyVAL.node = Node("Pow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 315:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:905
		{
			yyVAL.node = Node("Div").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 316:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:906
		{
			yyVAL.node = Node("Mod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 317:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:907
		{
			yyVAL.node = Node("ShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 318:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:908
		{
			yyVAL.node = Node("ShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 319:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:909
		{
			yyVAL.node = Node("UnaryPlus").append(yyDollar[2].node)
		}
	case 320:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:910
		{
			yyVAL.node = Node("UnaryMinus").append(yyDollar[2].node)
		}
	case 321:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:911
		{
			yyVAL.node = Node("BooleanNot").append(yyDollar[2].node)
		}
	case 322:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:912
		{
			yyVAL.node = Node("BitwiseNot").append(yyDollar[2].node)
		}
	case 323:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:913
		{
			yyVAL.node = Node("Identical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 324:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:914
		{
			yyVAL.node = Node("NotIdentical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 325:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:915
		{
			yyVAL.node = Node("Equal").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 326:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:916
		{
			yyVAL.node = Node("NotEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 327:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:917
		{
			yyVAL.node = Node("Spaceship").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 328:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:918
		{
			yyVAL.node = Node("Smaller").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 329:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:919
		{
			yyVAL.node = Node("SmallerOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 330:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:920
		{
			yyVAL.node = Node("Greater").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 331:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:921
		{
			yyVAL.node = Node("GreaterOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 332:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:922
		{
			yyVAL.node = yyDollar[2].node
		}
	case 333:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:923
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 334:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:924
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 335:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:925
		{
			yyVAL.node = Node("Coalesce").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 336:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:926
		{
			yyVAL.node = Node("Empty").append(yyDollar[3].node)
		}
	case 337:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:927
		{
			yyVAL.node = Node("Include").append(yyDollar[2].node)
		}
	case 338:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:928
		{
			yyVAL.node = Node("IncludeOnce").append(yyDollar[2].node)
		}
	case 339:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:929
		{
			yyVAL.node = Node("Eval").append(yyDollar[3].node)
		}
	case 340:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:930
		{
			yyVAL.node = Node("Require").append(yyDollar[2].node)
		}
	case 341:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:931
		{
			yyVAL.node = Node("RequireOnce").append(yyDollar[2].node)
		}
	case 342:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:932
		{
			yyVAL.node = Node("CastInt").append(yyDollar[2].node)
		}
	case 343:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:933
		{
			yyVAL.node = Node("CastDouble").append(yyDollar[2].node)
		}
	case 344:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:934
		{
			yyVAL.node = Node("CastString").append(yyDollar[2].node)
		}
	case 345:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:935
		{
			yyVAL.node = Node("CastArray").append(yyDollar[2].node)
		}
	case 346:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:936
		{
			yyVAL.node = Node("CastObject").append(yyDollar[2].node)
		}
	case 347:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:937
		{
			yyVAL.node = Node("CastBool").append(yyDollar[2].node)
		}
	case 348:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:938
		{
			yyVAL.node = Node("CastUnset").append(yyDollar[2].node)
		}
	case 349:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:939
		{
			yyVAL.node = Node("Silence").append(yyDollar[2].node)
		}
	case 350:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:940
		{
			yyVAL.node = yyDollar[1].node
		}
	case 351:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:941
		{
			yyVAL.node = Node("Print").append(yyDollar[2].node)
		}
	case 352:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:942
		{
			yyVAL.node = Node("Yield")
		}
	case 353:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:943
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node)
		}
	case 354:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:944
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 355:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:945
		{
			yyVAL.node = Node("YieldFrom").append(yyDollar[2].node)
		}
	case 356:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:949
		{
			yyVAL.node = Node("Scalar").append(Node("Lnumber").attribute("value", yyDollar[1].token))
		}
	case 357:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:950
		{
			yyVAL.node = Node("Scalar").append(Node("Dnumber").attribute("value", yyDollar[1].token))
		}
	case 358:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:951
		{
			yyVAL.node = Node("Scalar").append(Node("__LINE__"))
		}
	case 359:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:952
		{
			yyVAL.node = Node("Scalar").append(Node("__FILE__"))
		}
	case 360:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:953
		{
			yyVAL.node = Node("Scalar").append(Node("__DIR__"))
		}
	case 361:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:954
		{
			yyVAL.node = Node("Scalar").append(Node("__TRAIT__"))
		}
	case 362:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:955
		{
			yyVAL.node = Node("Scalar").append(Node("__METHOD__"))
		}
	case 363:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:956
		{
			yyVAL.node = Node("Scalar").append(Node("__FUNCTION__"))
		}
	case 364:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:957
		{
			yyVAL.node = Node("Scalar").append(Node("__NAMESPACE__"))
		}
	case 365:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:958
		{
			yyVAL.node = Node("Scalar").append(Node("__CLASS__"))
		}
	case 366:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:960
		{
			yyVAL.node = Node("Scalar").append(Node("Heredoc").attribute("value", yyDollar[2].token))
		}
	case 367:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:962
		{
			yyVAL.node = Node("Scalar").append(Node("Heredoc"))
		}
	case 368:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:963
		{
			yyVAL.node = yyDollar[2].node
		}
	case 369:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:964
		{
			yyVAL.node = yyDollar[2].node
		}
	case 370:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:965
		{
			yyVAL.node = yyDollar[1].node
		}
	case 371:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:966
		{
			yyVAL.node = yyDollar[1].node
		}
	case 372:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:970
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 373:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:971
		{
			yyVAL.node = yyDollar[1].node.append(Node("String").attribute("value", yyDollar[2].token))
		}
	case 374:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:972
		{
			yyVAL.node = Node("EncapsList").append(yyDollar[1].node)
		}
	case 375:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:973
		{
			yyVAL.node = Node("EncapsList").append(Node("String").attribute("value", yyDollar[1].token)).append(yyDollar[2].node)
		}
	case 376:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:976
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token)
		}
	case 377:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:977
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token).append(Node("offset").append(yyDollar[3].node))
		}
	case 378:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:978
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token).append(Node("property").attribute("value", yyDollar[3].token))
		}
	case 379:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:979
		{
			yyVAL.node = Node("Variable").append(Node("expr").append(yyDollar[2].node))
		}
	case 380:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:980
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token)
		}
	case 381:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:982
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token).append(Node("offset").append(yyDollar[4].node))
		}
	case 382:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:983
		{
			yyVAL.node = yyDollar[2].node
		}
	case 383:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:986
		{
			yyVAL.node = Node("OffsetString").attribute("value", yyDollar[1].token)
		}
	case 384:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:987
		{
			yyVAL.node = Node("OffsetNumString").attribute("value", yyDollar[1].token)
		}
	case 385:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:988
		{
			yyVAL.node = Node("OffsetNegateNumString").attribute("value", yyDollar[2].token)
		}
	case 386:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:989
		{
			yyVAL.node = Node("OffsetVariable").attribute("value", yyDollar[1].token)
		}
	case 387:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:993
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node)
		}
	case 388:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:994
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 389:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:996
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 390:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1000
		{
			yyVAL.node = Node("Static")
		}
	case 391:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1001
		{
			yyVAL.node = yyDollar[1].node
		}
	case 392:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1005
		{
			yyVAL.node = yyDollar[1].node
		}
	case 393:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1009
		{
			yyVAL.node = yyDollar[1].node
		}
	case 394:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1010
		{
			yyVAL.node = yyDollar[2].node
		}
	case 395:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1011
		{
			yyVAL.node = yyDollar[1].node
		}
	case 396:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1015
		{
			yyVAL.node = yyDollar[3].node
		}
	case 397:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1016
		{
			yyVAL.node = yyDollar[2].node
		}
	case 398:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1017
		{
			yyVAL.node = Node("String").attribute("value", yyDollar[1].token)
		}
	case 399:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1021
		{
			yyVAL.node = yyDollar[1].node
		}
	case 400:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1022
		{
			yyVAL.node = yyDollar[1].node
		}
	case 401:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1026
		{
			yyVAL.node = Node("")
		}
	case 402:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1027
		{
			yyVAL.node = yyDollar[1].node
		}
	case 403:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1031
		{
			yyVAL.node = yyDollar[1].node
		}
	case 404:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1035
		{
			yyVAL.node = yyDollar[1].node
		}
	case 405:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1036
		{
			yyVAL.node = yyDollar[1].node
		}
	case 406:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1037
		{
			yyVAL.node = Node("Property").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 407:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1041
		{
			yyVAL.node = Node("PropertyName").attribute("value", yyDollar[1].token)
		}
	case 408:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1042
		{
			yyVAL.node = yyDollar[2].node
		}
	case 409:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1043
		{
			yyVAL.node = yyDollar[1].node
		}
	case 410:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1047
		{
			yyVAL.node = Node("Variable").attribute("name", yyDollar[1].token)
		}
	case 411:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1048
		{
			yyVAL.node = Node("Variable").append(yyDollar[3].node)
		}
	case 412:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1049
		{
			yyVAL.node = Node("Variable").append(yyDollar[2].node)
		}
	case 413:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1054
		{
			yyVAL.node = Node("StaticProp").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 414:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1056
		{
			yyVAL.node = Node("StaticProp").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	}
	goto yystack /* stack new state and value */
}
